:orphan:

.. _cite_info:

License & Citation Information
------------------------------
DSPS is free software made available under a 
`3-clause BSD License <https://github.com/ArgonneCPAC/dsps/blob/main/LICENSE.rst/>`__.
If you use this package, please cite `Hearin et al. (2022) <https://arxiv.org/abs/2112.06830>`_::

    @ARTICLE{2023MNRAS.521.1741H,
          author = {{Hearin}, Andrew P. and {Chaves-Montero}, Jon{\'a}s and {Alarcon}, Alex and {Becker}, Matthew R. and {Benson}, Andrew},
            title = "{DSPS: Differentiable stellar population synthesis}",
          journal = {MNRAS},
        keywords = {software: data analysis, galaxies: stellar content, cosmology: large-scale structure of Universe, Astrophysics - Astrophysics of Galaxies, Astrophysics - Cosmology and Nongalactic Astrophysics},
            year = 2023,
            month = may,
          volume = {521},
          number = {2},
            pages = {1741-1756},
              doi = {10.1093/mnras/stad456},
    archivePrefix = {arXiv},
          eprint = {2112.06830},
    primaryClass = {astro-ph.GA},
          adsurl = {https://ui.adsabs.harvard.edu/abs/2023MNRAS.521.1741H},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
